@@ -8,26 +8,6 @@ This module provides the framework for altering and querying igraph parameters
 as well as saving them to and retrieving them from disk.
 """
 
-__license__ = """\
-Copyright (C) 2006-2012  Tamás Nepusz <ntamas@gmail.com>
-Pázmány Péter sétány 1/a, 1117 Budapest, Hungary
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301 USA
-"""
-
 import sys
 
 if sys.version_info < (3, 2):
@@ -40,7 +20,13 @@ import os.path
 
 
 def get_platform_image_viewer():
-    """Returns the path of an image viewer on the given platform"""
+    """Returns the path of an image viewer on the given platform.
+
+    Deprecated since python-igraph 0.9.1 and will be removed in 0.10.0.
+
+    @deprecated: This function was only used by the now-deprecated C{show()}
+        method of the Plot class.
+    """
     plat = platform.system()
     if plat == "Darwin":
         # Most likely Mac OS X
@@ -109,9 +95,9 @@ class Configuration(object):
     This object provides an interface to the configuration data using the
     syntax known from dict:
 
-      >>> c=Configuration()
+      >>> c = Configuration()
       >>> c["general.verbose"] = True
-      >>> print c["general.verbose"]
+      >>> print(c["general.verbose"])
       True
 
     Configuration keys are organized into sections, and the name to be used
@@ -121,9 +107,9 @@ class Configuration(object):
     If the name of the section is omitted, it defaults to C{general}, so
     C{general.verbose} can be referred to as C{verbose}:
 
-      >>> c=Configuration()
+      >>> c = Configuration()
       >>> c["verbose"] = True
-      >>> print c["general.verbose"]
+      >>> print(c["general.verbose"])
       True
 
     User-level configuration is stored in C{~/.igraphrc} per default on Linux
@@ -195,12 +181,8 @@ class Configuration(object):
 
         - B{ipython.inlining.Plot}: whether to show instances of the L{Plot} class
           inline in IPython's console if the console supports it. Default: C{True}
-
-    @undocumented: _item_to_section_key, _types, _sections, _definitions, _instance
     """
 
-    # pylint: disable-msg=R0903
-    # R0903: too few public methods
     class Types(object):
         """Static class for the implementation of custom getter/setter functions
         for configuration keys"""
